package com.muyu.etl.service.impl;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.muyu.etl.mapper.AssetImpowerMapper;
import com.muyu.etl.domain.AssetImpower;
import com.muyu.etl.service.AssetImpowerService;

/**
 * 资产赋权Service业务层处理
 *
 * @author Saisai
 * @date 2024-04-28
 */
@Service
public class AssetImpowerServiceImpl extends ServiceImpl<AssetImpowerMapper,AssetImpower> implements AssetImpowerService
{
    @Autowired
    private AssetImpowerMapper assetImpowerMapper;

    /**
     * 查询资产赋权
     *
     * @param id 资产赋权主键
     * @return 资产赋权
     */
    @Override
    public AssetImpower selectAssetImpowerById(Long id)
    {
        return assetImpowerMapper.selectAssetImpowerById(id);
    }

    /**
     * 查询资产赋权列表
     *
     * @param assetImpower 资产赋权
     * @return 资产赋权
     */
    @Override
    public List<AssetImpower> selectAssetImpowerList(AssetImpower assetImpower)
    {
        return assetImpowerMapper.selectAssetImpowerList(assetImpower);
    }

    /**
     * 新增资产赋权
     *
     * @param assetImpower 资产赋权
     * @return 结果
     */
    @Override
    public int insertAssetImpower(AssetImpower assetImpower)
    {
        assetImpower.setCreateTime(DateUtils.getNowDate());
        return assetImpowerMapper.insertAssetImpower(assetImpower);
    }

    /**
     * 修改资产赋权
     *
     * @param assetImpower 资产赋权
     * @return 结果
     */
    @Override
    public int updateAssetImpower(AssetImpower assetImpower)
    {
        assetImpower.setUpdateTime(DateUtils.getNowDate());
        return assetImpowerMapper.updateAssetImpower(assetImpower);
    }

    /**
     * 批量删除资产赋权
     *
     * @param ids 需要删除的资产赋权主键
     * @return 结果
     */
    @Override
    public int deleteAssetImpowerByIds(Long[] ids)
    {
        return assetImpowerMapper.deleteAssetImpowerByIds(ids);
    }

    /**
     * 删除资产赋权信息
     *
     * @param id 资产赋权主键
     * @return 结果
     */
    @Override
    public int deleteAssetImpowerById(Long id)
    {
        return assetImpowerMapper.deleteAssetImpowerById(id);
    }
}
